import { defineComponent, toRef, computed, createBlock, openBlock, resolveDynamicComponent, normalizeClass, unref, withCtx, renderSlot, createCommentVNode, createElementVNode, toDisplayString } from "vue";
import useSize, { sizeProps } from "../../composables/useSize/index.js";
import useVariant, { variantProps } from "../../composables/useVariant/index.js";
import useClasses from "../../composables/useClasses/index.js";
import useStringTemplate from "../../composables/useStringTemplate/index.js";
const _hoisted_1 = { class: "visually-hidden" }, types = ["border", "grow"], _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "Spinner",
  props: {
    ...sizeProps,
    /**
     * The type of the spinner
     * @values 'border'|'grow'
     */
    type: {
      type: String,
      default: "border",
      validator: (t) => types.includes(t)
    },
    ...variantProps,
    /**
     * Text content to place in the sr-only label
     */
    label: {
      type: String,
      default: "Loading..."
    },
    /**
     * Sets the ARIA attribute `role` to a specific value
     */
    role: {
      type: String,
      default: "status"
    },
    /**
     * When set, rendered a smaller spinner suitable for placing in buttons
     */
    small: {
      type: Boolean,
      default: !1
    },
    /**
     * Specify the HTML tag to render instead of the default tag
     */
    tag: {
      type: String,
      default: "span"
    }
  },
  setup(__props) {
    const props = __props, spinnerClass = useStringTemplate("spinner-{0}", toRef(props, "type")).templatedString, { classes } = useClasses(computed(() => [
      useSize(props.size, `${spinnerClass.value}-{0}`).sizeClass.value,
      spinnerClass.value,
      useVariant(props.variant, "text-{0}").variantClass.value,
      {
        "spinner-border-sm": props.small && props.type === "border",
        "spinner-grow-sm": props.small && props.type === "grow"
      }
    ]));
    return (_ctx, _cache) => (openBlock(), createBlock(resolveDynamicComponent(__props.tag), {
      class: normalizeClass(unref(classes)),
      role: __props.role,
      "aria-label": __props.label
    }, {
      default: withCtx(() => [
        _ctx.$slots.label ? renderSlot(_ctx.$slots, "label", { key: 0 }, () => [
          createElementVNode("span", _hoisted_1, toDisplayString(__props.label), 1)
        ]) : createCommentVNode("", !0)
      ]),
      _: 3
    }, 8, ["class", "role", "aria-label"]));
  }
});
export {
  _sfc_main as default,
  types
};
//# sourceMappingURL=Spinner.vue.js.map
