# Spinner

A loading spinner component that can be used to indicate loading states in your application.

```vue
<!-- Basic usage -->
<Spinner />

<!-- With custom size -->
<Spinner size="lg" />

<!-- With custom variant -->
<Spinner variant="primary" />

<!-- With custom label -->
<Spinner label="Please wait..." />

<!-- Small spinner -->
<Spinner small />

<!-- Custom tag -->
<Spinner tag="div" />

<!-- With custom label slot -->
<Spinner>
  <template #label>Custom loading message</template>
</Spinner>
```

## Imported Props

| Prop name | Description                  | Type                                             | Values | Default   |
| --------- | ---------------------------- | ------------------------------------------------ | ------ | --------- |
| size      | The size of the component    | [Size](../../composables/useSize) (string)       | -      | 'md'      |
| variant   | The variant of the component | [Variant](../../composables/useVariant) (string) | -      | 'primary' |

## Props

| Prop name | Description                  | Type                                             | Values | Default   |
| --------- | ---------------------------- | ------------------------------------------------ | ------ | --------- |
| type      | Type of spinner to show      | String                                           | 'border'\|'grow' | 'border' |
| label     | Text content for screen reader | String                                         | -      | 'Loading...' |
| role      | ARIA role attribute          | String                                           | -      | 'status'  |
| small     | Renders a smaller spinner    | Boolean                                          | -      | false     |
| tag       | HTML tag to render           | String                                           | -      | 'span'    |

## Slots

| Name  | Description |
| ----- | ----------- |
| label | Content to place in the sr-only label |

## Accessibility

The Spinner component is built with accessibility in mind:
- Uses ARIA role="status" by default
- Includes screen reader text via the `label` prop or slot
- Maintains proper contrast ratios for visibility
- Provides visual feedback for loading states

## Notes

- All props have sensible defaults and are optional
- The component supports both border and grow spinner types
- Small variant is particularly useful for inline loading states in buttons
- Custom HTML tags can be used via the `tag` prop
